@@ -1,7 +1,3 @@
-from __future__ import division
-from __future__ import print_function
-from future import standard_library
-standard_library.install_aliases()
 from past.utils import old_div
 from ckanext.datajson.harvester_base import DatasetHarvesterBase
 
