@@ -1,7 +1,3 @@
-from __future__ import print_function
-
-from future import standard_library
-standard_library.install_aliases()
 import json
 import logging
 import http.server
